GOparser Modules
================

Overview
--------

The `GOParser` class provides the API for parsing and accessing GO terms and
annotations. Each GO term is represented by a `GOTerm` object, and each GO
anntoation is represented by a `GOAnnotation` object.

Module List
-----------

.. toctree::
    :glob:

    api/goparser.*
